# redsem

Funcionalidades para convertir datos tabulares en redes semánticas

## Documentación
Por el momento la documentación se encuentra en este [sitio](https://redsem.readthedocs.io/es/latest/index.html)

## Instalación

```python
pip install redsem
```